Authentication Mixin
====================

Server-side authentication via BasicAuthMixin.

BasicAuthMixin
--------------

.. automodule:: genro_asgi.server.auth_mixin
   :members:
   :undoc-members:
   :show-inheritance:
